This page provides some tips on how to upgrade agent services between different versions of the `open-autonomy` framework. For full release notes check the <a href="https://github.com/valory-xyz/open-autonomy/tags" target="_blank">Open-Autonomy repo</a>.

Below we describe the additional manual steps required to upgrade between different versions:


# Open Autonomy

## `v0.1.0rc1` to `v0.1.0`

